@@ -40,6 +40,8 @@
 #include <QNetworkReply>
 #include <QDesktopServices>
 #include <QSettings>
+#include "fetauthenticationdialog.h"
+#include <QAuthenticator>
 
 #include <QDebug>
 
@@ -60,7 +62,8 @@ FetCamImage::FetCamImage(
     currentTimerInterval(5000),
     numberOfRedirections(0),
     networkAccessible(true),
-    sleeping(false)
+    sleeping(false),
+    authDialog(0)
 {
   setAlignment(Qt::AlignCenter);
 
@@ -70,7 +73,9 @@ FetCamImage::FetCamImage(
   loadFileDialog = new FetLoadFileDialog(parent);
   messenger = new FetMessenger(parent);
   timer = new QTimer();
+  authDialog = new FetAuthenticationDialog(parent);
 
+  // Handle Selector Dialog signals:
   connect(
     selectorDialog,
     SIGNAL(addNewTag(QString)),
@@ -95,12 +100,14 @@ FetCamImage::FetCamImage(
     messenger,
     SLOT(sendMessage(QString)));
 
+  // Handle Filter Dialog Signals:
   connect(
     tagDialog,
     SIGNAL(selectByTag(QString)),
     selectorDialog,
     SLOT(filterList(QString)));
 
+  // Handle Load File Dialog signals:
   connect(
     loadFileDialog,
     SIGNAL(newCamList(FetCamCollection)),
@@ -113,6 +120,7 @@ FetCamImage::FetCamImage(
     messenger,
     SLOT(sendMessage(QString)));
 
+  // Handle QNetworkAccessManager signals:
   connect(
     &qnam,
     SIGNAL(finished(QNetworkReply *)),
@@ -129,6 +137,17 @@ FetCamImage::FetCamImage(
       parseNetworkAccessibility(
         QNetworkAccessManager::NetworkAccessibility)));
 
+  connect(
+    &qnam,
+    SIGNAL(
+      authenticationRequired(
+        QNetworkReply*, QAuthenticator*)),
+    this,
+    SLOT(
+      performAuthentication(
+        QNetworkReply*, QAuthenticator*)));
+
+  // Manage Timer signals:
   connect(
     timer,
     SIGNAL(timeout()),
@@ -248,6 +267,18 @@ void FetCamImage::retrieveImage()
   }
 
   currentReply = qnam.get(QNetworkRequest(QUrl(currentWebcamUrl)));
+
+  connect(
+    currentReply,
+    SIGNAL(error(QNetworkReply::NetworkError)),
+    this,
+    SLOT(handleReplyError(QNetworkReply::NetworkError)));
+
+  connect(
+    currentReply,
+    SIGNAL(sslErrors(QList<QSslError>)),
+    this,
+    SLOT(handleReplySslErrors(QList<QSslError>)));
 }
 
 
@@ -560,3 +591,44 @@ void FetCamImage::exitSleepMode()
     retrieveImage();
   }
 }
+
+
+void FetCamImage::performAuthentication(
+  QNetworkReply *reply,
+  QAuthenticator *auth)
+{
+//qDebug() << reply->readAll();
+  authDialog->exec();
+
+  if (authDialog->wasAccepted())
+  {
+    auth->setUser(authDialog->getUser());
+    auth->setPassword(authDialog->getPassword());
+  }
+  else
+  {
+    // Cancel the current request:
+    timer->stop();
+    if (currentReply)
+    {
+      currentReply->abort();
+      currentReply->deleteLater();
+      currentReply = 0;
+    }
+  }
+}
+
+
+void FetCamImage::handleReplyError(
+  QNetworkReply::NetworkError error)
+{
+qDebug() << "QNetworkReply Error: " << error;
+  // Should inform the user about this...
+}
+
+
+void FetCamImage::handleReplySslErrors(
+  QList<QSslError> errors)
+{
+qDebug() << "SSL Errors: " << errors;
+}
