@@ -27,6 +27,9 @@
 #include <QPixmap>
 #include <QNetworkAccessManager>
 #include "fettargetarchitecture.h"
+#include <QList>
+#include <QSslError>
+#include <QNetworkReply>
 
 #ifdef MAEMO_OS
 #include "fetdbus.h"
@@ -46,6 +49,8 @@ class FetCamWidgetItem;
 class QTimer;
 class QNetworkReply;
 class QResizeEvent;
+class FetAuthenticationDialog;
+class QAuthenticator;
 
 class FetCamImage: public QLabel
 {
@@ -103,6 +108,16 @@ private slots:
   void enterSleepMode();
   void exitSleepMode();
 
+  void performAuthentication(
+    QNetworkReply *reply,
+    QAuthenticator *auth);
+
+  void handleReplyError(
+    QNetworkReply::NetworkError error);
+
+  void handleReplySslErrors(
+    QList<QSslError> errors);
+
 private:
   QByteArray *imageData;
   QBuffer *imageBuffer;
@@ -128,6 +143,8 @@ private:
   bool networkAccessible;
   bool sleeping;
 
+  FetAuthenticationDialog *authDialog;
+
 #ifdef MAEMO_OS
   FetDBus dbusListener;
 #endif // MAEMO_OS
